@@ -4,6 +4,7 @@
  * Copyright (C) 2004-2006 Elijah Newren
  * Copyright (C) 2013 Red Hat Inc.
  * Copyright (C) 2017-2019 Alberts Muktupāvels
+ * Copyright (C) 2020 NVIDIA CORPORATION
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +29,6 @@
 #include <libgnome-desktop/gnome-pnp-ids.h>
 
 #include "gf-backend-private.h"
-#include "gf-dbus-display-config.h"
 #include "gf-display-config-shared.h"
 #include "gf-monitor-manager-enums-private.h"
 #include "gf-monitor-manager-types-private.h"
@@ -52,6 +52,8 @@ struct _GfMonitorManager
 
   GfDBusDisplayConfig         *display_config;
 
+  gboolean                     in_init;
+
   guint                        serial;
 
   GfLogicalMonitorLayoutMode   layout_mode;
@@ -138,6 +140,9 @@ typedef struct
                                                                  gint                        *max_height);
 
   GfLogicalMonitorLayoutMode   (* get_default_layout_mode)      (GfMonitorManager            *manager);
+
+  void                         (* set_output_ctm)               (GfOutput                    *output,
+                                                                 const GfOutputCtm           *ctm);
 } GfMonitorManagerClass;
 
 GType                       gf_monitor_manager_get_type                     (void);
