@@ -269,6 +269,10 @@ calculate_scale (GfMonitor                 *monitor,
       case GF_CONNECTOR_TYPE_eDP:
       case GF_CONNECTOR_TYPE_VIRTUAL:
       case GF_CONNECTOR_TYPE_DSI:
+      case GF_CONNECTOR_TYPE_DPI:
+      case GF_CONNECTOR_TYPE_WRITEBACK:
+      case GF_CONNECTOR_TYPE_SPI:
+      case GF_CONNECTOR_TYPE_USB:
       default:
         break;
     }
@@ -711,13 +715,14 @@ gchar *
 gf_monitor_mode_spec_generate_id (GfMonitorModeSpec *spec)
 {
   gboolean is_interlaced;
-  gchar refresh_rate[G_ASCII_DTOSTR_BUF_SIZE];
 
   is_interlaced = !!(spec->flags & GF_CRTC_MODE_FLAG_INTERLACE);
-  g_ascii_dtostr (refresh_rate, G_ASCII_DTOSTR_BUF_SIZE, spec->refresh_rate);
 
-  return g_strdup_printf ("%dx%d%s@%s", spec->width, spec->height,
-                          is_interlaced ? "i" : "", refresh_rate);
+  return g_strdup_printf ("%dx%d%s@%.3f",
+                          spec->width,
+                          spec->height,
+                          is_interlaced ? "i" : "",
+                          (double) spec->refresh_rate);
 }
 
 GfMonitorSpec *
@@ -776,6 +781,17 @@ gf_monitor_is_underscanning (GfMonitor *monitor)
   return gf_output_is_underscanning (output);
 }
 
+gboolean
+gf_monitor_get_max_bpc (GfMonitor    *self,
+                        unsigned int *max_bpc)
+{
+  GfOutput *output;
+
+  output = gf_monitor_get_main_output (self);
+
+  return gf_output_get_max_bpc (output, max_bpc);
+}
+
 gboolean
 gf_monitor_is_laptop_panel (GfMonitor *monitor)
 {
@@ -804,6 +820,10 @@ gf_monitor_is_laptop_panel (GfMonitor *monitor)
       case GF_CONNECTOR_TYPE_DisplayPort:
       case GF_CONNECTOR_TYPE_TV:
       case GF_CONNECTOR_TYPE_VIRTUAL:
+      case GF_CONNECTOR_TYPE_DPI:
+      case GF_CONNECTOR_TYPE_WRITEBACK:
+      case GF_CONNECTOR_TYPE_SPI:
+      case GF_CONNECTOR_TYPE_USB:
       default:
         break;
     }
@@ -966,6 +986,25 @@ gf_monitor_get_mode_from_id (GfMonitor   *monitor,
   return g_hash_table_lookup (priv->mode_ids, monitor_mode_id);
 }
 
+gboolean
+gf_monitor_mode_spec_has_similar_size (GfMonitorModeSpec *monitor_mode_spec,
+                                       GfMonitorModeSpec *other_monitor_mode_spec)
+{
+  const float target_ratio = 1.0;
+  /* The a size difference of 15% means e.g. 4K modes matches other 4K modes,
+   * FHD (2K) modes other FHD modes, and HD modes other HD modes, but not each
+   * other.
+   */
+  const float epsilon = 0.15;
+
+  return G_APPROX_VALUE (((float) monitor_mode_spec->width /
+                          other_monitor_mode_spec->width) *
+                         ((float) monitor_mode_spec->height /
+                          other_monitor_mode_spec->height),
+                         target_ratio,
+                         epsilon);
+}
+
 GfMonitorMode *
 gf_monitor_get_mode_from_spec (GfMonitor         *monitor,
                                GfMonitorModeSpec *monitor_mode_spec)
